@@ -17,7 +17,8 @@ use {
     solana_ledger::{blockstore::Blockstore, blockstore_db::AccessType},
     solana_sdk::{clock::Slot, pubkey::Pubkey, signature::Signature},
     solana_transaction_status::{
-        ConfirmedBlockWithOptionalMetadata, EncodedTransaction, UiTransactionEncoding,
+        BlockEncodingOptions, Encodable, EncodeError, LegacyConfirmedBlock, TransactionDetails,
+        UiTransactionEncoding,
     },
     std::{
         collections::HashSet,
@@ -73,10 +74,27 @@ async fn block(slot: Slot, output_format: OutputFormat) -> Result<(), Box<dyn st
         .await
         .map_err(|err| format!("Failed to connect to storage: {:?}", err))?;
 
-    let block = bigtable.get_confirmed_block(slot).await?;
+    let confirmed_block = bigtable.get_confirmed_block(slot).await?;
+    let encoded_block = confirmed_block
+        .encode_with_options(
+            UiTransactionEncoding::Base64,
+            BlockEncodingOptions {
+                transaction_details: TransactionDetails::Full,
+                show_rewards: true,
+                max_supported_transaction_version: None,
+            },
+        )
+        .map_err(|err| match err {
+            EncodeError::UnsupportedTransactionVersion(version) => {
+                format!(
+                    "Failed to process unsupported transaction version ({}) in block",
+                    version
+                )
+            }
+        })?;
 
     let cli_block = CliBlock {
-        encoded_confirmed_block: block.encode(UiTransactionEncoding::Base64),
+        encoded_confirmed_block: encoded_block.into(),
         slot,
     };
     println!("{}", output_format.formatted_string(&cli_block));
@@ -153,16 +171,20 @@ async fn confirm(
     let mut get_transaction_error = None;
     if verbose {
         match bigtable.get_confirmed_transaction(signature).await {
-            Ok(Some(confirmed_transaction)) => {
+            Ok(Some(confirmed_tx)) => {
+                let legacy_confirmed_tx = confirmed_tx
+                    .into_legacy_confirmed_transaction()
+                    .ok_or_else(|| "Failed to read versioned transaction in block".to_string())?;
+
                 transaction = Some(CliTransaction {
-                    transaction: EncodedTransaction::encode(
-                        confirmed_transaction.transaction.transaction.clone(),
-                        UiTransactionEncoding::Json,
-                    ),
-                    meta: confirmed_transaction.transaction.meta.map(|m| m.into()),
-                    block_time: confirmed_transaction.block_time,
-                    slot: Some(confirmed_transaction.slot),
-                    decoded_transaction: confirmed_transaction.transaction.transaction,
+                    transaction: legacy_confirmed_tx
+                        .tx_with_meta
+                        .transaction
+                        .encode(UiTransactionEncoding::Json),
+                    meta: legacy_confirmed_tx.tx_with_meta.meta.map(|m| m.into()),
+                    block_time: legacy_confirmed_tx.block_time,
+                    slot: Some(legacy_confirmed_tx.slot),
+                    decoded_transaction: legacy_confirmed_tx.tx_with_meta.transaction,
                     prefix: "  ".to_string(),
                     sigverify_status: vec![],
                 });
@@ -194,7 +216,7 @@ pub async fn transaction_history(
 ) -> Result<(), Box<dyn std::error::Error>> {
     let bigtable = solana_storage_bigtable::LedgerStorage::new(true, None, None).await?;
 
-    let mut loaded_block: Option<(Slot, ConfirmedBlockWithOptionalMetadata)> = None;
+    let mut loaded_block: Option<(Slot, LegacyConfirmedBlock)> = None;
     while limit > 0 {
         let results = bigtable
             .get_confirmed_signatures_for_address(
@@ -245,7 +267,11 @@ pub async fn transaction_history(
                                 Some(transaction_with_meta) => {
                                     println_transaction(
                                         &transaction_with_meta.transaction,
-                                        &transaction_with_meta.meta.clone().map(|m| m.into()),
+                                        transaction_with_meta
+                                            .meta
+                                            .clone()
+                                            .map(|m| m.into())
+                                            .as_ref(),
                                         "  ",
                                         None,
                                         None,
@@ -260,7 +286,10 @@ pub async fn transaction_history(
                             println!("  Unable to get confirmed transaction details: {}", err);
                             break;
                         }
-                        Ok(block) => {
+                        Ok(confirmed_block) => {
+                            let block = confirmed_block.into_legacy_block().ok_or_else(|| {
+                                "Failed to read versioned transaction in block".to_string()
+                            })?;
                             loaded_block = Some((result.slot, block));
                         }
                     }
